import { Context } from "./context";
import * as Inputs from "./inputs";
import { Vector, DrawHelperCore, JSCADText } from "@bitbybit-dev/core";
import { JSCADWorkerManager } from "@bitbybit-dev/core/lib/workers";
import { OCCTWorkerManager } from "@bitbybit-dev/occt-worker";
import { BufferGeometry, Group, MeshPhysicalMaterial } from "three";
export declare class DrawHelper extends DrawHelperCore {
    private readonly context;
    private readonly solidText;
    readonly vector: Vector;
    private readonly jscadWorkerManager;
    private readonly occWorkerManager;
    private usedMaterials;
    constructor(context: Context, solidText: JSCADText, vector: Vector, jscadWorkerManager: JSCADWorkerManager, occWorkerManager: OCCTWorkerManager);
    /**
     * Draws OpenCascade shape by going through faces and edges
     * @param inputs Contains a shape to be drawn and additional information
     * @returns ThreeJS Group
     * @group drawing
     * @shortname draw shape
     * @drawable false
     * @ignore true
     */
    drawShape(inputs: Inputs.OCCT.DrawShapeDto<Inputs.OCCT.TopoDSShapePointer>): Promise<Group>;
    /**
     * Draws OpenCascade shapes by going through faces and edges
     * @param inputs Contains shapes to be drawn and additional information
     * @returns ThreeJS Group
     * @group drawing
     * @shortname draw shapes
     * @drawable false
     * @ignore true
     */
    drawShapes(inputs: Inputs.OCCT.DrawShapesDto<Inputs.OCCT.TopoDSShapePointer>): Promise<Group>;
    /**
     * Draws a single solids
     * @param inputs Contains a solid or polygon and information for drawing
     * @returns Group containing mesh that is being drawn by ThreeJS
     * @group jscad
     * @shortname draw solid
     * @ignore true
     */
    drawSolidOrPolygonMesh(inputs: Inputs.JSCAD.DrawSolidMeshDto<Group>): Promise<Group>;
    /**
     * Draws multiple solids
     * @param inputs Contains solids or polygons and information for drawing
     * @returns Mesh that is being drawn by ThreeJS
     * @group jscad
     * @shortname draw solids
     * @ignore true
     */
    drawSolidOrPolygonMeshes(inputs: Inputs.JSCAD.DrawSolidMeshesDto<Group>): Promise<Group>;
    drawPolylinesWithColours(inputs: Inputs.Polyline.DrawPolylinesDto<Group>): Group<import("three").Object3DEventMap>;
    drawPoint(inputs: Inputs.Point.DrawPointDto<Group>): Group;
    /**
     * Draws a single polyline and handle closed case
     * @param inputs Contains a polyline to be drawn
     * @returns Lines mesh that is being drawn by Babylon
     */
    drawPolylineClose(inputs: Inputs.Polyline.DrawPolylineDto<Group>): Group;
    drawPolyline(mesh: Group, pointsToDraw: Inputs.Base.Point3[], updatable: boolean, size: number, opacity: number, colours: string | string[]): Group;
    /**
     * Draws a single curve
     * @param inputs Contains a curve to be drawn
     * @returns Lines mesh that is being drawn by Babylon
     */
    drawCurve(inputs: Inputs.Verb.DrawCurveDto<Group>): Group;
    private parseFaces;
    private makeMesh;
    private createMesh;
    private handleDecomposedMesh;
    private drawPolylines;
    drawPoints(inputs: Inputs.Point.DrawPointsDto<Group>): Group;
    updatePointsInstances(group: Group, positions: Inputs.Base.Point3[]): void;
    /**
     * Draws multiple curves
     * @param inputs Contains curves to be drawn
     * @returns Lines mesh that is being drawn by threejs
     */
    drawCurves(inputs: Inputs.Verb.DrawCurvesDto<Group>): Group;
    /**
     * Draws multiple surfaces with multiple colours. Number of colours has to be equal to number of surfaces
     * @param inputs Contains the Nurbs surfaces, colours and other information for drawing
     * @returns Mesh that is being drawn by Babylon
     */
    drawSurfacesMultiColour(inputs: Inputs.Verb.DrawSurfacesColoursDto<Group>): Group;
    private createPointSpheresMesh;
    createOrUpdateSurfacesMesh(meshDataConverted: {
        positions: number[];
        indices: number[];
        normals: number[];
        uvs?: number[];
    }[], group: Group, updatable: boolean, material: MeshPhysicalMaterial, addToScene: boolean, hidden: boolean): Group;
    /**
     * Draws a single surface
     * @param inputs Contains a surface and information for drawing
     * @returns Mesh that is being drawn by Babylon
     */
    drawSurface(inputs: Inputs.Verb.DrawSurfaceDto<Group>): Group;
    createGeometries(decomposedMesh: Inputs.OCCT.DecomposedMeshDto): BufferGeometry[];
}
